//
//	aegis - project change supervisor
//	Copyright (C) 1997, 2002-2005 Peter Miller;
//	All rights reserved.
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: functions to manipulate now tree nodes
//

#include <libaegis/aer/value/time.h>
#include <common/now.h>
#include <aefind/tree.h>
#include <aefind/tree/constant.h>
#include <aefind/tree/now.h>


tree_ty *
tree_now_new(void)
{
    static rpt_value_ty *vp;

    if (!vp)
	vp = rpt_value_time(now());
    return tree_constant_new(vp);
}
